@@ -120,7 +120,7 @@ void k9MenuEdit::urBackgroundSelected(const TQString &_fileName) {
 //...otherwise, set the menu background image
         TQImage img;
         img.load(_fileName);
-        img=img.smoothScale(720,m_imageHeight,TQ_ScaleMax);
+        img=img.smoothScale(720,m_imageHeight,TQImage::ScaleMax);
         setBackgroundImage(img);
     }
 }
