@@ -59,7 +59,7 @@ void k9BurnDVD::setburnDevice( const TQString& _newVal) {
 /** Write property of TQString workDir. */
 void k9BurnDVD::setworkDir( const TQString& _newVal) {
     workDir = _newVal;
-    if (workDir.right(1)!='/')
+    if (workDir.right(1)!="/")
         workDir +='/';
 }
 
