@@ -258,7 +258,7 @@ TQString k9DVD::lang_name(const TQString& code,const TQString & name) {
                 c = l.name;
             }
         } else {
-            if (strcmp(name.latin1(),l.name)==0) {
+            if (name == l.name) {
                 c = l.code;
             }
 
