@@ -404,7 +404,7 @@ const TQString& k9DVDAuthor::getworkDir() {
 }
 void k9DVDAuthor::setworkDir( const TQString& _newVal) {
     workDir = _newVal;
-    if (workDir.right(1)!='/')
+    if (workDir.right(1)!="/")
         workDir +='/';
 }
 
