@@ -28,7 +28,7 @@
   */
 
 class k9DVDProgress : public DVDProgress  {
-Q_OBJECT
+TQ_OBJECT
   
 public: 
 	k9DVDProgress(TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
