@@ -15,9 +15,9 @@
 #include <tqeventloop.h>
 
 k9Process::k9Process(TQObject *parent, const char *name)
- : KProcess(parent, name),m_waitSync(false)
+ : TDEProcess(parent, name),m_waitSync(false)
 {
-   connect(this,TQT_SIGNAL(processExited( KProcess* )),this,TQT_SLOT(slotProcessExited( KProcess* )));
+   connect(this,TQT_SIGNAL(processExited( TDEProcess* )),this,TQT_SLOT(slotProcessExited( TDEProcess* )));
  
 }
 
@@ -32,7 +32,7 @@ void k9Process::sync() {
 }
 
 
-void k9Process::slotProcessExited( KProcess * proc) {
+void k9Process::slotProcessExited( TDEProcess * proc) {
    if (m_waitSync) {
    	TQApplication::eventLoop()->exitLoop();
    	m_waitSync=false;	
@@ -49,7 +49,7 @@ const TQString & k9Process::debug() {
 
 bool  k9Process::start (RunMode runmode, Communication comm) {
   m_elapsed.start();
-  return KProcess::start(runmode,comm);
+  return TDEProcess::start(runmode,comm);
 }
 #include "k9process.moc"
 
