@@ -1190,7 +1190,7 @@ void k9Main::extractMPEG2() {
  
     for (int i=0; i < dvd->gettitleCount();i++) {
         k9DVDTitle *t=dvd->gettitle(i);
-        changeStatusbar( i18n("Extracting title : %1",t->getname()) ,sbMessage);
+        changeStatusbar( i18n("Extracting title : %1").arg(t->getname()) ,sbMessage);
 								
         if (t->isSelected() && t->getIndexed() ) {
             TQString name;
